/**
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "Exolab" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of Exoffice Technologies.  For written permission,
 *    please contact info@exolab.org.
 *
 * 4. Products derived from this Software may not be called "Exolab"
 *    nor may "Exolab" appear in their names without prior written
 *    permission of Exoffice Technologies. Exolab is a registered
 *    trademark of Exoffice Technologies.
 *
 * 5. Due credit should be given to the Exolab Project
 *    (http://www.exolab.org/).
 *
 * THIS SOFTWARE IS PROVIDED BY EXOFFICE TECHNOLOGIES AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * EXOFFICE TECHNOLOGIES OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 2000 (C) Exoffice Technologies Inc. All Rights Reserved.
 *
 */
 
package org.exolab.tools.ant;

// java io
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.PrintStream;

// java utility
import java.util.Properties;

// ant
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.Project;


/**
 * Ant task that increments a property in a property file, and makes the
 * property available to the Ant environment
 *
 * @version     $Revision: 1.1.1.1 $ $Date: 2002/01/22 00:21:38 $
 * @author      <a href="mailto:tima@intalio.com">Tim Anderson</a>
 */
public class Increment extends Task {

    /**
     * The property file
     */
    private File _file = null;

    /**
     * The name of the property to increment.
     */
    private String _property = null;

    /**
     * Constructor
     */
    public Increment() {
    }

    public void setFile(File file) {
        _file = file;
    }

    public void setProperty(String property) {
        _property = property;
    }

    public void execute() throws BuildException {
        if (_file == null) {
            throw new BuildException("No property file specified");
        }
        if (_property == null) {
            throw new BuildException("No property specified");
        }

        Properties properties = new Properties();
        try {
            if (_file.exists()) {
                FileInputStream input = new FileInputStream(_file);
                try {
                    properties.load(input);
                } finally {
                    if (input != null) {
                        input.close();
                    }
                }

                String value = properties.getProperty(_property);
                if (value != null) {
                    int number = Integer.parseInt(value) + 1;
                    value = String.valueOf(number);
                    properties.setProperty(_property, value);
                    project.setProperty(_property, value);

                    FileOutputStream output = new FileOutputStream(_file);
                    try {
                        properties.store(output, null); //null is for no header
                    } finally {
                        if (output != null) {
                            output.flush();
                            output.close();
                        }
                    }
                }
            } else {
                throw new BuildException("Property file does not exist: " +
                                         _file.getAbsolutePath());
            }
        } catch(Exception exception) {
            throw new BuildException(exception);
        }
    }

} //-- Increment
