/**
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "Exolab" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of Exoffice Technologies.  For written permission,
 *    please contact info@exolab.org.
 *
 * 4. Products derived from this Software may not be called "Exolab"
 *    nor may "Exolab" appear in their names without prior written
 *    permission of Exoffice Technologies. Exolab is a registered
 *    trademark of Exoffice Technologies.
 *
 * 5. Due credit should be given to the Exolab Project
 *    (http://www.exolab.org/).
 *
 * THIS SOFTWARE IS PROVIDED BY EXOFFICE TECHNOLOGIES AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * EXOFFICE TECHNOLOGIES OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 2000 (C) Exoffice Technologies Inc. All Rights Reserved.
 *
 */
 
package org.exolab.tools.ant;

// regexp
import org.apache.oro.text.regex.MalformedPatternException;
import org.apache.oro.text.regex.Pattern;
import org.apache.oro.text.regex.PatternMatcher;
import org.apache.oro.text.regex.Perl5Compiler;
import org.apache.oro.text.regex.Perl5Matcher;
import org.apache.oro.text.regex.Perl5Substitution;
import org.apache.oro.text.regex.Util;

// ant
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.Project;


/**
 * Ant task that performs pattern substitution on an existing property.
 *
 * @version     $Revision: 1.1.1.1 $ $Date: 2002/01/22 00:21:39 $
 * @author      <a href="mailto:tima@intalio.com">Tim Anderson</a>
 */
public class Substitute extends Task {

    /**
     * The name of the property to translate.
     */
    private String _property = null;

    /**
     * The regular expression pattern
     */
    private String _pattern = null;

    /**
     * The text to replace pattern matches with
     */
    private String _text = null;

    /**
     * Constructor
     */
    public Substitute() {
    }

    public void setProperty(String property) {
        _property = property;
    }

    public void setPattern(String pattern) {
        _pattern = pattern;
    }

    public void setText(String text) {
        _text = text;
    }

    public void execute() throws BuildException {
        if (_property == null) {
            throw new BuildException("No property specified");
        }
        if (_pattern == null) {
            throw new BuildException("No pattern specified");
        }
        if (_text == null) {
            throw new BuildException("No replacement text specified");
        }

        String value = project.getProperty(_property);
        PatternMatcher matcher = new Perl5Matcher();
        Perl5Substitution subst = new Perl5Substitution(
            _text, Perl5Substitution.INTERPOLATE_ALL);

        if (value != null) {
            try {
                Perl5Compiler compiler = new Perl5Compiler();
                Pattern pattern = compiler.compile(_pattern);
                value = Util.substitute(matcher, pattern, subst, value,
                                         Util.SUBSTITUTE_ALL);
                project.setProperty(_property, value);
            } catch (MalformedPatternException exception) {
                throw new BuildException(
                    "Invalid regular expression pattern: " + _pattern);
            }
        }
    }

} //-- Substitute
